@@ -36,6 +36,7 @@ from __future__ import absolute_import, print_function
 import copy
 import sys
 import re
+import time
 from typing import TYPE_CHECKING, Any, Callable, Container, Iterable, List, Match, Optional, Tuple, Type, Union  # noqa: F401
 
 import six
@@ -623,8 +624,30 @@ class policiesGroup:
 		self.members = members
 
 
+def _ldap_cache(ttl=10, cache_none=True):
+	def _decorator(func):
+		func._cache = {}
+
+		def _decorated(lo, *args):
+			cache = func._cache
+			key = tuple([id(lo)] + list(args))
+			now = time.time()
+			for cache_key, cache_val in list(cache.items()):
+				if cache_val['expire'] < now:
+					cache.pop(cache_key)
+
+			if key not in cache or cache[key]['expire'] < now:
+				value = {'value': func(lo, *args), 'expire': time.time() + ttl}
+				if value['value'] is None and not cache_none:
+					return
+				cache[key] = value
+			return cache[key]['value']
+		return _decorated
+	return _decorator
+
+
 univention.admin = sys.modules[__name__]
-from univention.admin import modules, objects, syntax, hook, mapping  # noqa: F401
+from univention.admin import modules, objects, syntax, hook, mapping  # noqa: F401,E402
 syntax.import_syntax_files()
 hook.import_hook_files()
 
