@@ -33,7 +33,7 @@
 
 from __future__ import absolute_import
 
-from typing import Mapping, Sequence, Union  # noqa F401
+from typing import Mapping, Sequence, Union  # noqa: F401
 
 
 def month_map(month):
