@@ -860,6 +860,12 @@ layout = [
 ]
 
 
+@univention.admin._ldap_cache(ttl=10, cache_none=False)
+def get_primary_group_dn(lo, gid_number):
+	groups = lo.searchDn(filter=filter_format(u'(&(|(objectClass=posixGroup)(objectClass=sambaGroupMapping))(gidNumber=%s))', [gid_number]))
+	return groups[0] if groups else None
+
+
 def check_prohibited_username(lo, username):
 	"""check if the username is allowed"""
 	module = univention.admin.modules.get('settings/prohibited_username')
@@ -1378,15 +1384,15 @@ class object(univention.admin.handlers.simpleLdap):
 	def _load_groups(self, loadGroups):
 		if self.exists():
 			if loadGroups:  # this is optional because it can take much time on larger installations, default is true
-				self['groups'] = [x.decode('UTF-8') if six.PY2 else x for x in self.lo.searchDn(filter=filter_format(u'(&(cn=*)(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping))(uniqueMember=%s))', [self.dn]))]
+				self['groups'] = [x.decode('UTF-8') if six.PY2 else x for x in self.lo.searchDn(filter=filter_format(u'(&(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping))(uniqueMember=%s))', [self.dn]))]
 			else:
 				ud.debug(ud.ADMIN, ud.INFO, 'user: open with loadGroups=false for user %s' % self['username'])
 			self.groupsLoaded = loadGroups
 			primaryGroupNumber = self.oldattr.get('gidNumber', [b''])[0].decode('ASCII')
 			if primaryGroupNumber:
-				primaryGroupResult = self.lo.searchDn(filter=filter_format(u'(&(cn=*)(|(objectClass=posixGroup)(objectClass=sambaGroupMapping))(gidNumber=%s))', [primaryGroupNumber]))
-				if primaryGroupResult:
-					self['primaryGroup'] = primaryGroupResult[0]
+				primary_group = get_primary_group_dn(self.lo, primaryGroupNumber)
+				if primary_group:
+					self['primaryGroup'] = primary_group
 				else:
 					try:
 						primaryGroup = self.lo.search(filter='(objectClass=univentionDefault)', base='cn=univention,' + self.position.getDomain(), attr=['univentionDefaultGroup'])
